summaryrefslogtreecommitdiff
path: root/src/imports/location/qdeclarativegeomapmousearea.cpp
diff options
context:
space:
mode:
authorjuhvu <qt-info@nokia.com>2011-08-11 15:02:29 +1000
committerabcd <qt_abcd1@ovi.com>2011-08-12 05:06:19 +0200
commit469170b584d14e045418a71b34fb648cc6f9b726 (patch)
tree05eca519008a620f109077838e8a6b2581e05b05 /src/imports/location/qdeclarativegeomapmousearea.cpp
parent3f7102d1eef9f5070ecc0033415b057a966d9f0d (diff)
downloadqtlocation-469170b584d14e045418a71b34fb648cc6f9b726.tar.gz
Modified location QML tests to work in QML2 environment.
Also added freetext geocoding and a small feature for clearing all featureWeights of a routing query. Change-Id: Idfe5000bb335fc2825fc14108de154e6e86ba0ef Reviewed-on: http://codereview.qt.nokia.com/2840 Reviewed-by: Qt Sanity Bot <qt_sanity_bot@ovi.com> Reviewed-by: abcd <qt_abcd1@ovi.com>
Diffstat (limited to 'src/imports/location/qdeclarativegeomapmousearea.cpp')
-rw-r--r--src/imports/location/qdeclarativegeomapmousearea.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/imports/location/qdeclarativegeomapmousearea.cpp b/src/imports/location/qdeclarativegeomapmousearea.cpp
index f6efe35b..761da7aa 100644
--- a/src/imports/location/qdeclarativegeomapmousearea.cpp
+++ b/src/imports/location/qdeclarativegeomapmousearea.cpp
@@ -78,8 +78,8 @@ QT_BEGIN_NAMESPACE
\sa MapMouseEvent
*/
-QDeclarativeGeoMapMouseArea::QDeclarativeGeoMapMouseArea(QDeclarativeItem *parent)
- : QDeclarativeItem(parent),
+QDeclarativeGeoMapMouseArea::QDeclarativeGeoMapMouseArea(QSGItem *parent)
+ : QSGItem(parent),
enabled_(true),
hoverEnabled_(false) {}
@@ -265,7 +265,7 @@ void QDeclarativeGeoMapMouseArea::setHoverEnabled(bool hoverEnabled)
return;
hoverEnabled_ = hoverEnabled;
- setAcceptsHoverEvents(hoverEnabled_);
+ //setAcceptsHoverEvents(hoverEnabled_);
setAcceptHoverEvents(hoverEnabled_);
setAcceptedMouseButtons(Qt::LeftButton);
emit hoverEnabledChanged(hoverEnabled_);
@@ -281,7 +281,7 @@ void QDeclarativeGeoMapMouseArea::setHoverEnabled(bool hoverEnabled)
void QDeclarativeGeoMapMouseArea::doubleClickEvent(QDeclarativeGeoMapMouseEvent *event)
{
if (!enabled_) {
//TODO QDeclarativeItem::mouseDoubleClickEvent(convert event to regular event here)
return;
}
// TODO check this properly
@@ -292,7 +292,7 @@ void QDeclarativeGeoMapMouseArea::doubleClickEvent(QDeclarativeGeoMapMouseEvent
// TODO save event
event->setAccepted(doubleClickConnected);
emit doubleClicked(event);
// TODO QDeclarativeItem::mouseDoubleClickEvent(convert event to regular event here)
map_->setActiveMouseArea(0);
}
@@ -300,7 +300,7 @@ void QDeclarativeGeoMapMouseArea::doubleClickEvent(QDeclarativeGeoMapMouseEvent
void QDeclarativeGeoMapMouseArea::pressEvent(QDeclarativeGeoMapMouseEvent *event)
{
if (!enabled_) {
//TODO QDeclarativeItem::mousePressEvent(convert event to regular event here)
return;
}
@@ -324,7 +324,7 @@ void QDeclarativeGeoMapMouseArea::pressEvent(QDeclarativeGeoMapMouseEvent *event
void QDeclarativeGeoMapMouseArea::releaseEvent(QDeclarativeGeoMapMouseEvent *event)
{
if (!enabled_) {
//TODO QDeclarativeItem::mouseReleaseEvent(convert event to regular event here)
return;
}
@@ -281,7 +281,7 @@ void QDeclarativeGeoMapMouseArea::setHoverEnabled(bool hoverEnabled)
{
if (!enabled_) {
- //TODO QDeclarativeItem::mouseDoubleClickEvent(convert event to regular event here)
+ //TODO QSGItem::mouseDoubleClickEvent(convert event to regular event here)
return;
}
@@ -292,7 +292,7 @@ void QDeclarativeGeoMapMouseArea::doubleClickEvent(QDeclarativeGeoMapMouseEvent
event->setAccepted(doubleClickConnected);
emit doubleClicked(event);
- // TODO QDeclarativeItem::mouseDoubleClickEvent(convert event to regular event here)
+ // TODO QSGItem::mouseDoubleClickEvent(convert event to regular event here)
map_->setActiveMouseArea(0);
}
@@ -300,7 +300,7 @@ void QDeclarativeGeoMapMouseArea::doubleClickEvent(QDeclarativeGeoMapMouseEvent
{
if (!enabled_) {
- //TODO QDeclarativeItem::mousePressEvent(convert event to regular event here)
+ //TODO QSGItem::mousePressEvent(convert event to regular event here)
return;
}
@@ -324,7 +324,7 @@ void QDeclarativeGeoMapMouseArea::pressEvent(QDeclarativeGeoMapMouseEvent *event
{
if (!enabled_) {
- //TODO QDeclarativeItem::mouseReleaseEvent(convert event to regular event here)
+ //TODO QSGItem::mouseReleaseEvent(convert event to regular event here)
return;
}